"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("mz/fs");
const path = require("path");
const yargs = require("yargs");
const index_1 = require("./index");
const theme_1 = require("./theme");
yargs
    .option('theme', {
    alias: 't',
    nargs: 1,
    description: 'Use a theme defined in a JSON file',
})
    .usage(['', 'Usage: highlight [options] [file]', '', 'Outputs a file or STDIN input with syntax highlighting'].join('\n'))
    .option('language', {
    alias: 'l',
    nargs: 1,
    description: 'Set the langugage explicitely\nIf omitted will try to auto-detect',
})
    .version(() => require('../../package.json').version)
    .help('help')
    .alias('help', 'h')
    .alias('version', 'v');
const argv = yargs.argv;
const file = argv._[0];
let codePromise;
if (!file && !process.stdin.isTTY) {
    // Input from STDIN
    process.stdin.setEncoding('utf8');
    let code = '';
    process.stdin.on('readable', () => {
        const chunk = process.stdin.read();
        if (chunk !== null) {
            code += chunk;
        }
    });
    codePromise = new Promise(resolve => {
        process.stdin.on('end', () => {
            const chunk = process.stdin.read();
            if (chunk !== null) {
                code += chunk;
            }
            resolve(code);
        });
    });
}
else if (file) {
    // Read file
    codePromise = fs.readFile(file, 'utf-8');
}
else {
    yargs.showHelp();
    process.exit(1);
}
Promise.all([codePromise, argv.theme ? fs.readFile(argv.theme, 'utf8') : undefined])
    .then(([code, theme]) => {
    const options = {
        ignoreIllegals: true,
        theme: theme && theme_1.parse(theme),
    };
    if (file) {
        const ext = path.extname(file).substr(1);
        if (ext && index_1.supportsLanguage(ext)) {
            options.language = ext;
        }
    }
    options.language = argv.language;
    return new Promise((resolve, reject) => process.stdout.write(index_1.highlight(code, options), (err) => (err ? reject(err) : resolve())));
})
    .then(() => {
    process.exit(0);
})
    .catch((err) => {
    console.error(err);
    process.exit(1);
});
//# sourceMappingURL=cli.js.map